unit DCal3D;

// Delphi 6PE port of Cal3D (C) 2001 Paul TOTH <tothpaul@free.fr>
// Cal3D-0.6 (4. Aug. 2001) (C) 2001 Bruno 'Beosil' Heidelberger

{
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}

// 24 Nov. 2001, first lines of code :)

(* Translation notes :
  -------------------

  - Delphi classes are pointers :
  ----------- Delphi --------------+---------- C -------------------------------
  var                              | {
   MyInstance:TMyClass;            |   TMyClass *MyInstance;
  begin                            |
   MyInstance:=TMyClass.Create;    |   MyInstance=new TMyClass;
  ------------------------------------------+-----------------------------------
  - Delphi use a "." for classes fields, not "->"

  - Static classes aren't available under Delphi.
  ----------- C -------------------+---------- Delphi --------------------------
  {                                |
   TMyClass MyClasse;              |  need the same code as above !
                                   |
                                   |
  ---------------------------------+--------------------------------------------

  - Function returned value is called "Result", it can be read and write

  - There's no "return" keyword, use "Result:=Value; exit;"

  - C "FOR", look like a While for Delphi, Delphi "FOR" have no exit condition.
  -----------C---------------------------+--------Delphi------------------------
   for (i=0; i<10; i++) {                | for i:=0 to 9 do begin
   }                                     | end;
                                         |
   for (i=0; (i<10)&&(s[i]); i++, j++) { | i:=0; while (i<10)and(s[i]<>0) do begin
   }                                     | inc(i); inc(j); end;
                                         |
   for(; childCount > 0; childCount--) { | while ChildCount>0 do begin
   }                                     | dec(ChildCount); end;
  ------------------------------------------------------------------------------

  - null pointer is "nil"; pointer isn't integer, can't assign 0 to a pointer !

  - float => single

  - Delphi "Property" can replace get/set method :
  -----------C---------------------------+--------Delphi------------------------
   class MyClass {                       | MyClass=class
    private:                             |  private
     int m_Field;                        |   m_Field:integer;
    public:                              |  public
     int getField();                     |   property Field:integer read m_Field write m_Field;
     void setField(int value);           | end;
   }                                     | //you can also use get/set method !
                                         | //property Field:integer read getField write setField;
  ------------------------------------------------------------------------------
  - I've replaced :
   * vector class by Delphi dynamic arrays : reserve -> SetLength()
   * list by TList
   * map by dynamic arrays of record...

*)
interface

uses
 Classes; // TList

const
  fmOpenRead       = $0000;
  fmOpenWrite      = $0001;
  fmOpenReadWrite  = $0002;

{$ifdef win32}
  fmShareCompat    = $0000;
  fmShareExclusive = $0010;
  fmShareDenyWrite = $0020;
  fmShareDenyRead  = $0030;
  fmShareDenyNone  = $0040;
{$else}
  fmShareDenyNone  = $0030;
{$endif}
type
 float=single;

function fmod(a,b:float):float;

// global.h

// global typedefs
Type
 CalUserData=integer;

const
// file magic cookies
 SKELETON_FILE_MAGIC:array[0..3] of char  = 'CSF'#0;
 ANIMATION_FILE_MAGIC:array[0..3] of char = 'CAF'#0;
 MESH_FILE_MAGIC:array[0..3] of char      = 'CMF'#0;
 MATERIAL_FILE_MAGIC:array[0..3] of char  = 'CRF'#0;

// library version
 LIBRARY_VERSION = 600;

// file versions
 CURRENT_FILE_VERSION : integer = LIBRARY_VERSION;
 EARLIEST_COMPATIBLE_FILE_VERSION = 600;

Type
// forwards
 CalAnimation=class;
 CalAnimationAction=class;
 CalAnimationCycle=class;
 CalBone=class;
 CalCoreAnimation=class;
 CalCoreBone=class;
 CalCoreKeyframe=class;
 CalCoreMaterial=class;
 CalCoreMesh=class;
 CalCoreModel=class;
 CalCoreSkeleton=class;
 CalCoreSubmesh=class;
 CalCoreTrack=class;
 CalError=class;
 CalLoader=class;
 CalMesh=class;
 CalMixer=class;
 CalModel=class;
 CalQuaternion=class;
 CalRenderer=class;
 CalSaver=class;
 CalSkeleton=class;
 CalSubmesh=class;
 CalVector=class;

// vector
 CalAnimations=array of CalAnimation;
 CalBones=array of CalBone;
 CalCoreAnimations=array of CalCoreAnimation;
 CalCoreBones=array of CalCoreBone;
 CalCoreKeyframes=array of record id:float; item:CalCoreKeyframe end; // map
 CalCoreMaterials=array of CalCoreMaterial;
 CalCoreMeshes=array of CalCoreMesh;
 CalCoreSubmeshes=array of CalCoreSubmesh;
 CalMeshes=array of CalMesh;
 CalSubmeshes=array of CalSubmesh;

// .h
 {$i animation.int}
 {$i animation_action.int}
 {$i animation_cycle.int}
 {$i bone.int}
 {$i coreanimation.int}
 {$i corebone.int}
 {$i corekeyframe.int}
 {$i corematerial.int}
 {$i coremesh.int}
 {$i coremodel.int}
 {$i coreskeleton.int}
 {$i coresubmesh.int}
 {$i coretrack.int}
 {$i error.int}
 {$i loader.int}
 {$i mesh.int}
 {$i mixer.int}
 {$i model.int}
 {$i quaternion.int}
 {$i renderer.int}
 {$i saver.int}
 {$i skeleton.int}
 {$i submesh.int}
 {$i vector.int}

implementation

// some C function unavailable under Delphi

Uses
 Math; // ArcCos()

function fmod(a,b:float):float;
 begin
  result:=a-(b*int(a/b));
 end;

// .c
 {$i animation.imp}
 {$i animation_action.imp}
 {$i animation_cycle.imp}
 {$i bone.imp}
 {$i coreanimation.imp}
 {$i corebone.imp}
 {$i corekeyframe.imp}
 {$i corematerial.imp}
 {$i coremesh.imp}
 {$i coremodel.imp}
 {$i coreskeleton.imp}
 {$i coresubmesh.imp}
 {$i coretrack.imp}
 {$i error.imp}
 {$i loader.imp}
 {$i mesh.imp}
 {$i mixer.imp}
 {$i model.imp}
 {$i quaternion.imp}
 {$i renderer.imp}
 {$i saver.imp}
 {$i skeleton.imp}
 {$i submesh.imp}
 {$i vector.imp}


end.
